from typing import Optional, List
from pydantic import BaseModel
from datetime import datetime

class NotificationBase(BaseModel):
    title: str
    message: str
    notification_type: str
    priority: str = "normal"

class NotificationCreate(NotificationBase):
    recipient_ids: List[int]

class NotificationUpdate(BaseModel):
    title: Optional[str] = None
    message: Optional[str] = None
    notification_type: Optional[str] = None
    priority: Optional[str] = None

class NotificationInDBBase(NotificationBase):
    id: int
    sender_id: int
    created_at: datetime
    updated_at: Optional[datetime] = None

    class Config:
        orm_mode = True

class Notification(NotificationInDBBase):
    pass