from fastapi import FastAPI
from fastapi.middleware.cors import CORSMiddleware

# Create basic app without complex imports
app = FastAPI(
    title="School Portal API",
    version="1.0.0",
    description="School Portal API - A comprehensive school management system",
    openapi_url="/openapi.json",
    docs_url="/docs",
    redoc_url="/redoc"
)

app.add_middleware(
    CORSMiddleware,
    allow_origins=["*"],
    allow_credentials=True,
    allow_methods=["*"],
    allow_headers=["*"],
)

@app.get("/")
async def root():
    return {
        "title": "School Portal API",
        "version": "1.0.0",
        "description": "School Portal API - A comprehensive school management system",
        "documentation": "/docs",
        "health": "/health"
    }

@app.get("/health")
async def health_check():
    return {"status": "healthy", "service": "School Portal API"}

# Try to import and include API routes
try:
    from app.core.config import settings
    from app.api.v1.api import api_router
    
    app.include_router(api_router, prefix="/api/v1")
    print("✓ API routes loaded successfully")
except Exception as e:
    print(f"⚠️ Warning: Could not load API routes: {e}")
    # Add a simple test route instead
    @app.get("/api/v1/test")
    async def test():
        return {"message": "API routes not loaded, but basic app is working"}